# RobotHub SDK

RobotHub SDK is a Python package allowing to communicate with RobotHub platform

## Installation

To install this package, run the following command in your terminal window

```
$ python3 -m pip install robothub-sdk
```

> :warning: **If you're using Raspberry Pi**, providing a Pi Wheels extra package url can significantly speed up the installation process by providing prebuilt binaries for OpenCV
> ```
> $ pip install --extra-index-url https://www.piwheels.org/simple/ depthai-sdk
> ```

## Usage

TBD


## API

TBD
